@@ -1,19 +1,25 @@
 var group__pw__impl__port =
 [
+    [ "impl-port.h", "impl-port_8h.html", null ],
     [ "pw_impl_port_events", "structpw__impl__port__events.html", [
-      [ "control_added", "structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82", null ],
-      [ "control_removed", "structpw__impl__port__events.html#a9f23250e31672a49aa26a5dd5b593e80", null ],
+      [ "version", "structpw__impl__port__events.html#a7d76d0a7bef38963ff7c3e5a4fd9a1d3", null ],
       [ "destroy", "structpw__impl__port__events.html#a5595c734ed5c3fc9ab27c2f5244fa325", null ],
       [ "free", "structpw__impl__port__events.html#a7049ef85f5a0f35988c6a2f60a02c385", null ],
-      [ "info_changed", "structpw__impl__port__events.html#a69e18fd1facb78dbb42025c17ef0884a", null ],
       [ "initialized", "structpw__impl__port__events.html#a8ddfb5c4f95dafcf15e0e9d3df367169", null ],
-      [ "latency_changed", "structpw__impl__port__events.html#a74130c25a3cc6e05ef753847e17a85cb", null ],
+      [ "info_changed", "structpw__impl__port__events.html#a69e18fd1facb78dbb42025c17ef0884a", null ],
       [ "link_added", "structpw__impl__port__events.html#a73104e5c2b8f887977945a597fa6b1ee", null ],
       [ "link_removed", "structpw__impl__port__events.html#acae053d6b84259d9a475eda14ca670ed", null ],
-      [ "param_changed", "structpw__impl__port__events.html#a8d5a42f37e97b448cf6e1d7942677c81", null ],
       [ "state_changed", "structpw__impl__port__events.html#a77a67b128bc4961a1caa38572f8f6094", null ],
-      [ "version", "structpw__impl__port__events.html#a7d76d0a7bef38963ff7c3e5a4fd9a1d3", null ]
+      [ "control_added", "structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82", null ],
+      [ "control_removed", "structpw__impl__port__events.html#a9f23250e31672a49aa26a5dd5b593e80", null ],
+      [ "param_changed", "structpw__impl__port__events.html#a8d5a42f37e97b448cf6e1d7942677c81", null ],
+      [ "latency_changed", "structpw__impl__port__events.html#a74130c25a3cc6e05ef753847e17a85cb", null ],
+      [ "tag_changed", "structpw__impl__port__events.html#abf43e1309a677e920e0e818ed657a7f6", null ]
     ] ],
+    [ "pw_impl_port", "structpw__impl__port.html", null ],
+    [ "pw_impl_link", "structpw__impl__link.html", null ],
+    [ "pw_control", "structpw__control.html", null ],
+    [ "PW_VERSION_IMPL_PORT_EVENTS", "group__pw__impl__port.html#gab93bd5bf74abcd605281cac49fb0cc2b", null ],
     [ "pw_impl_port_state", "group__pw__impl__port.html#ga1d18e055b32143b9e11e8451a2da9234", [
       [ "PW_IMPL_PORT_STATE_ERROR", "group__pw__impl__port.html#gga1d18e055b32143b9e11e8451a2da9234a6925207b33ec5081f5fd4ba8c9d047fc", null ],
       [ "PW_IMPL_PORT_STATE_INIT", "group__pw__impl__port.html#gga1d18e055b32143b9e11e8451a2da9234a716979c51f23a424e5623109271174ed", null ],
@@ -22,13 +28,14 @@ var group__pw__impl__port =
       [ "PW_IMPL_PORT_STATE_PAUSED", "group__pw__impl__port.html#gga1d18e055b32143b9e11e8451a2da9234a75ca0b49eb6a11ea843cfdcb480b079b", null ]
     ] ],
     [ "pw_context_create_port", "group__pw__impl__port.html#ga006aa900c4a192b709b19916e31b782d", null ],
-    [ "pw_impl_port_add", "group__pw__impl__port.html#ga56cd7301e2c55e93f032c0e82562465a", null ],
-    [ "pw_impl_port_add_listener", "group__pw__impl__port.html#gacb4744ca242716128f55b470e6a4b734", null ],
     [ "pw_impl_port_get_direction", "group__pw__impl__port.html#ga9e553c2ffc8a8a70b325521af90a0cf9", null ],
-    [ "pw_impl_port_get_id", "group__pw__impl__port.html#gac28520f534eaa508ff1ea14122f842a9", null ],
-    [ "pw_impl_port_get_info", "group__pw__impl__port.html#gaf3c7764d7f42e9f4df666dfd7499e387", null ],
-    [ "pw_impl_port_get_node", "group__pw__impl__port.html#ga78f3d10b5af9c245095d9a22e59ceeb1", null ],
     [ "pw_impl_port_get_properties", "group__pw__impl__port.html#ga5682619e17eb12d4bd4c7d70e985e08c", null ],
+    [ "pw_impl_port_update_properties", "group__pw__impl__port.html#ga0a0c6321011b667f97d93cff9d0006d1", null ],
+    [ "pw_impl_port_get_info", "group__pw__impl__port.html#gaf3c7764d7f42e9f4df666dfd7499e387", null ],
+    [ "pw_impl_port_get_id", "group__pw__impl__port.html#gac28520f534eaa508ff1ea14122f842a9", null ],
+    [ "pw_impl_port_state_as_string", "group__pw__impl__port.html#gab293612d908dbe49f064c6eb874304cd", null ],
+    [ "pw_impl_port_get_node", "group__pw__impl__port.html#ga78f3d10b5af9c245095d9a22e59ceeb1", null ],
     [ "pw_impl_port_is_linked", "group__pw__impl__port.html#ga2f4e8293872dd04eabb559ed7f331f73", null ],
-    [ "pw_impl_port_update_properties", "group__pw__impl__port.html#ga0a0c6321011b667f97d93cff9d0006d1", null ]
+    [ "pw_impl_port_add", "group__pw__impl__port.html#ga56cd7301e2c55e93f032c0e82562465a", null ],
+    [ "pw_impl_port_add_listener", "group__pw__impl__port.html#gacb4744ca242716128f55b470e6a4b734", null ]
 ];
\ No newline at end of file
