@@ -1,6 +1,6 @@
 var group__pw__log =
 [
-    [ "src/pipewire/log.h", "src_2pipewire_2log_8h.html", null ],
+    [ "log.h", "src_2pipewire_2log_8h.html", null ],
     [ "PW_LOG_TOPIC_STATIC", "group__pw__log.html#ga17486e6b572efd349064cdf4a3d5cc4c", null ],
     [ "PW_LOG_TOPIC_EXTERN", "group__pw__log.html#ga96bec971316a5aa2fbc0e931efd0cbc6", null ],
     [ "PW_LOG_TOPIC", "group__pw__log.html#ga4634117c563f2c41b435e4312989d50c", null ],
@@ -28,7 +28,6 @@ var group__pw__log =
     [ "pw_log_logtv", "group__pw__log.html#ga0a7e025da6f12e4d2f5e35f045228bbf", null ],
     [ "pw_log_log", "group__pw__log.html#gad6f92d062fc6d4c8cd293cf29027b1de", null ],
     [ "pw_log_logv", "group__pw__log.html#ga3c2e22a8450c053fd61cc974613952d1", null ],
-    [ "_pw_log_topic_new", "group__pw__log.html#gae349441ea1f880353d14f780ee1de762", null ],
     [ "pw_log_level", "group__pw__log.html#gac5f33d3392f3df466736240c534f5dfe", null ],
     [ "PW_LOG_TOPIC_DEFAULT", "group__pw__log.html#gaafac687ae331d078de69f4a612a03dd6", null ]
 ];
\ No newline at end of file
