@@ -163,12 +163,16 @@ var group__pw__session__manager =
     [ "pw_client_session_update", "group__pw__session__manager.html#ga1df3e3242c1438fe35c454dd3ed41219", null ],
     [ "pw_client_session_link_update", "group__pw__session__manager.html#ga8b55930c438fa7f090ca2b03a9709c18", null ],
     [ "PW_TYPE_INTERFACE_Session", "group__pw__session__manager.html#gae9cbccb8f8ecae1b281d29d538d0f6f0", null ],
+    [ "PW_SESSION_PERM_MASK", "group__pw__session__manager.html#gaed0cfc07ccdb5a3e8c1578c9216279be", null ],
     [ "PW_VERSION_SESSION", "group__pw__session__manager.html#ga61c63491758436617fc59af4f263b4eb", null ],
     [ "PW_TYPE_INTERFACE_Endpoint", "group__pw__session__manager.html#gaa7bf956682a13c8dabda82c6c388b7e9", null ],
+    [ "PW_ENDPOINT_PERM_MASK", "group__pw__session__manager.html#gab9526991696ac2886e4d266c22d40594", null ],
     [ "PW_VERSION_ENDPOINT", "group__pw__session__manager.html#ga3126b0d16a1105a0075ffdc1b8d25fc4", null ],
     [ "PW_TYPE_INTERFACE_EndpointStream", "group__pw__session__manager.html#ga5bc56193f4eaa23ab2e494aab49249a7", null ],
+    [ "PW_ENDPOINT_STREAM_PERM_MASK", "group__pw__session__manager.html#gaeafaf4dbb69984ba067ad380debee99e", null ],
     [ "PW_VERSION_ENDPOINT_STREAM", "group__pw__session__manager.html#gaee511508513a161959dbc4e30b682dff", null ],
     [ "PW_TYPE_INTERFACE_EndpointLink", "group__pw__session__manager.html#ga93d8f2ddcda53c926ecc085fede31446", null ],
+    [ "PW_ENDPOINT_LINK_PERM_MASK", "group__pw__session__manager.html#gaa9d5f9aa179c065024484e0e1674d3a1", null ],
     [ "PW_VERSION_ENDPOINT_LINK", "group__pw__session__manager.html#gac90ad5edf844a20a969b19c48c2f1d18", null ],
     [ "PW_SESSION_EVENT_INFO", "group__pw__session__manager.html#ga7e51bfdb707f25b2222dfae9c6dc7dea", null ],
     [ "PW_SESSION_EVENT_PARAM", "group__pw__session__manager.html#ga66409c7725bcc8631015483d84f731c9", null ],
