@@ -8,6 +8,9 @@ var group__pw__utils =
     [ "pw_split_walk", "group__pw__utils.html#ga86777dfdd21dbb21a2c74470aad019a4", null ],
     [ "pw_split_strv", "group__pw__utils.html#gacdc181bb9d9a0be73f19ad2745630399", null ],
     [ "pw_split_ip", "group__pw__utils.html#gaada7b1ede9468dc38e00907c52c2969b", null ],
+    [ "pw_strv_parse", "group__pw__utils.html#gab14911d7b202c1f20ccbb175be94fd0d", null ],
+    [ "pw_strv_find", "group__pw__utils.html#ga0ff9fdcc34105fadd73b9feac583188b", null ],
+    [ "pw_strv_find_common", "group__pw__utils.html#gaaae124fb2f76b6caaf2fd424b2e3a7f0", null ],
     [ "pw_free_strv", "group__pw__utils.html#ga80e0ca15ccef3f20ef9524a26d8c2b45", null ],
     [ "pw_strip", "group__pw__utils.html#gab7c0e5ea4acd296a58642198133565c9", null ],
     [ "pw_getrandom", "group__pw__utils.html#gac9f252f07455653aebd285fc9e05feee", null ],
