@@ -1,5 +1,8 @@
 var NAVTREEINDEX18 =
 {
+"structpw__client__node__methods.html":[10,7,0,3],
+"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740":[10,7,0,3,6],
+"structpw__client__node__methods.html#a05968e322e128af7d58f1598ad61af7e":[10,7,0,3,1],
 "structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404":[10,7,0,3,2],
 "structpw__client__node__methods.html#a1db43e226468e68a6a52292aa6a894c6":[10,7,0,3,7],
 "structpw__client__node__methods.html#acf64a3bd71fd790592e41458a4793c62":[10,7,0,3,0],
@@ -246,8 +249,5 @@ var NAVTREEINDEX18 =
 "structpw__impl__node__events.html#a21b4486448a26b56eea0508a92c99035":[10,5,7,1,1],
 "structpw__impl__node__events.html#a347372b746a4f05fc0a6d8ecb1346dd6":[10,5,7,1,4],
 "structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f":[10,5,7,1,15],
-"structpw__impl__node__events.html#a5b8cbba5cb1b1d8574929dc73a915463":[10,5,7,1,12],
-"structpw__impl__node__events.html#a5ec09d921107cfaec7a569d07d7c1430":[10,5,7,1,0],
-"structpw__impl__node__events.html#a693dbb0bc91e07af02dc409dce738d6a":[10,5,7,1,2],
-"structpw__impl__node__events.html#a8a268deab9a29164fc8f9b57a9ee55e7":[10,5,7,1,8]
+"structpw__impl__node__events.html#a5b8cbba5cb1b1d8574929dc73a915463":[10,5,7,1,12]
 };
