@@ -1,5 +1,8 @@
 var NAVTREEINDEX20 =
 {
+"structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[10,7,4,18,2],
+"structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6":[10,7,4,18,1],
+"structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3":[10,7,4,18,0],
 "structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660":[10,7,4,18,4],
 "structpw__session__methods.html":[10,7,4,11],
 "structpw__session__methods.html#a39a82c063c97d967e5ee82589c390c29":[10,7,4,11,0],
@@ -246,8 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__device__object__info.html":[10,8,4,5],
 "structspa__device__object__info.html#a0758afd0518197c48d5d76cdc14526e3":[10,8,4,5,0],
 "structspa__device__object__info.html#a4ed767ff310d6f2e1d4cd78f3a7c3f6f":[10,8,4,5,1],
-"structspa__device__object__info.html#a702111c5873243c93551073552863666":[10,8,4,5,3],
-"structspa__device__object__info.html#a9b6645d2c0b8b3679833ad122cb299a1":[10,8,4,5,2],
-"structspa__device__object__info.html#aec61b33f732c10087d40e9c0d97bdcb0":[10,8,4,5,4],
-"structspa__dict.html":[10,8,8,2,2]
+"structspa__device__object__info.html#a702111c5873243c93551073552863666":[10,8,4,5,3]
 };
