@@ -1,5 +1,8 @@
 var NAVTREEINDEX7 =
 {
+"group__spa__cpu.html#ga330efa5c84b2b5777c715e1b708bab7d":[10,8,9,0,53],
+"group__spa__cpu.html#ga34938fa446a7f4078cb7da6877e855de":[10,8,9,0,25],
+"group__spa__cpu.html#ga34a7cfa724239e524fdccf570249abf3":[10,8,9,0,58],
 "group__spa__cpu.html#ga36f54e2aac3837cb3631db07cbfde3e2":[10,8,9,0,50],
 "group__spa__cpu.html#ga417908a823f8fc14cce2fa5ffc68aeb7":[10,8,9,0,24],
 "group__spa__cpu.html#ga43c86c77745486a5e63c4ac15f75875f":[10,8,9,0,8],
@@ -246,8 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__hooks.html#ga2c42d01721e8e9edd16e5062a880129f":[10,8,8,4,5],
 "group__spa__hooks.html#ga4f7f50596d9e2b4e3146ed89444ab8b2":[10,8,8,4,11],
 "group__spa__hooks.html#ga58d3375750cb16ee5dbcb8337af46cba":[10,8,8,4,6],
-"group__spa__hooks.html#ga63c54fcf4a4073e230e656f3275ebaea":[10,8,8,4,16],
-"group__spa__hooks.html#ga85ae35aa8df17a38bcc003e0a05e73cc":[10,8,8,4,3],
-"group__spa__hooks.html#ga9fb6df7a8c2a772b0cc39f81bc0eec03":[10,8,8,4,9],
-"group__spa__hooks.html#gab5d20379dc8a8a17e58631045e3f6323":[10,8,8,4,13]
+"group__spa__hooks.html#ga63c54fcf4a4073e230e656f3275ebaea":[10,8,8,4,16]
 };
