@@ -1,5 +1,8 @@
 var NAVTREEINDEX8 =
 {
+"group__spa__hooks.html#ga85ae35aa8df17a38bcc003e0a05e73cc":[10,8,8,4,3],
+"group__spa__hooks.html#ga9fb6df7a8c2a772b0cc39f81bc0eec03":[10,8,8,4,9],
+"group__spa__hooks.html#gab5d20379dc8a8a17e58631045e3f6323":[10,8,8,4,13],
 "group__spa__hooks.html#gacb30a0a53954eed2af8041a1882eef15":[10,8,8,4,14],
 "group__spa__hooks.html#gacbc74f9ceab3dc7c5d6d8c3eca6a41e5":[10,8,8,4,12],
 "group__spa__hooks.html#gadb7d27ebaa8d5997c5420910de1db773":[10,8,8,4,4],
@@ -246,8 +249,5 @@ var NAVTREEINDEX8 =
 "group__spa__loop.html#gaf08e046c937b0d412b56b0cccbeeebea":[10,8,9,4,13],
 "group__spa__loop.html#gaf18adfccc510004e0438614046e58013":[10,8,9,4,40],
 "group__spa__loop.html#gaf67b95b170f125ee503fec3640b727ca":[10,8,9,4,44],
-"group__spa__loop.html#gafdc6876cd766fafc297841accedcd105":[10,8,9,4,34],
-"group__spa__loop.html#gaffe08d7788d04fa44c44fda7ab3649bb":[10,8,9,4,30],
-"group__spa__names.html":[10,8,8,8],
-"group__spa__names.html#ga010bfd1f2c50f4927df733f5f13e5690":[10,8,8,8,23]
+"group__spa__loop.html#gafdc6876cd766fafc297841accedcd105":[10,8,9,4,34]
 };
