@@ -443,39 +443,42 @@ var searchData=
   ['pw_5fstream_5fupdate_5fparams_440',['pw_stream_update_params',['../group__pw__stream.html#ga0c274f28a9b9b2fe286719db159f166b',1,'stream.c']]],
   ['pw_5fstream_5fupdate_5fproperties_441',['pw_stream_update_properties',['../group__pw__stream.html#ga065b067d55def0d2c2cedf814a5c55d0',1,'stream.c']]],
   ['pw_5fstrip_442',['pw_strip',['../group__pw__utils.html#gab7c0e5ea4acd296a58642198133565c9',1,'utils.c']]],
-  ['pw_5fthread_5ffill_5fattr_443',['pw_thread_fill_attr',['../group__pw__thread.html#ga09ac2a140526a285e1af5e7ddd2fe672',1,'thread.c']]],
-  ['pw_5fthread_5floop_5faccept_444',['pw_thread_loop_accept',['../group__pw__thread__loop.html#ga7cc82c62d85014248b66db0947e4f087',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fadd_5flistener_445',['pw_thread_loop_add_listener',['../group__pw__thread__loop.html#ga4b32a1682ab076c733bed42808037328',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fdestroy_446',['pw_thread_loop_destroy',['../group__pw__thread__loop.html#ga58bf781b6f987e80d4a7a6796551dfb1',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fget_5floop_447',['pw_thread_loop_get_loop',['../group__pw__thread__loop.html#ga4f2403d0004550ba89f76af4df63dfaf',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fget_5ftime_448',['pw_thread_loop_get_time',['../group__pw__thread__loop.html#ga7257709ce22560b28da2525f812485e5',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fin_5fthread_449',['pw_thread_loop_in_thread',['../group__pw__thread__loop.html#gacb9c26a513d752803fd272a4ea2bc891',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5flock_450',['pw_thread_loop_lock',['../group__pw__thread__loop.html#gaa7996893e812e9eec61f786d1c691c54',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fnew_451',['pw_thread_loop_new',['../group__pw__thread__loop.html#gad05bec2017f1081bccec2f0def34e9d3',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fnew_5ffull_452',['pw_thread_loop_new_full',['../group__pw__thread__loop.html#gabdc2e68dfd070fe58770143f184fc026',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fsignal_453',['pw_thread_loop_signal',['../group__pw__thread__loop.html#gaf9bc8dd348d05b095139f5a55ac5a4b0',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fstart_454',['pw_thread_loop_start',['../group__pw__thread__loop.html#ga22e8e0f011e6406a4201a28b4592862e',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fstop_455',['pw_thread_loop_stop',['../group__pw__thread__loop.html#ga856c3aec5718bceb92d6169c42062186',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5ftimed_5fwait_456',['pw_thread_loop_timed_wait',['../group__pw__thread__loop.html#ga3eb85aa843de70d0488aa25aa2dc361c',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5ftimed_5fwait_5ffull_457',['pw_thread_loop_timed_wait_full',['../group__pw__thread__loop.html#gaf191188f2dc2ddfbc1e9bb84764709eb',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5funlock_458',['pw_thread_loop_unlock',['../group__pw__thread__loop.html#ga1f8042dce9da459ec61b6f3a2d6852d8',1,'thread-loop.c']]],
-  ['pw_5fthread_5floop_5fwait_459',['pw_thread_loop_wait',['../group__pw__thread__loop.html#gae97c812b1fa7696909d3e4419e4e079e',1,'thread-loop.c']]],
-  ['pw_5fthread_5futils_5fget_460',['pw_thread_utils_get',['../group__pw__thread.html#ga4f44f914821635ec123cf0a0ae2d0b5d',1,'thread.c']]],
-  ['pw_5fthread_5futils_5fset_461',['pw_thread_utils_set',['../group__pw__thread.html#ga57b388a269e2682fd9bc46bb9f46efec',1,'thread.c']]],
-  ['pw_5ftype_5finfo_462',['pw_type_info',['../group__pw__type.html#ga7fff23c226b8e3b4c6b172be4bd2401a',1,'pipewire.c']]],
-  ['pw_5funload_5fspa_5fhandle_463',['pw_unload_spa_handle',['../group__pw__pipewire.html#gaf3d7686492ea5032eb135cddf21d3da2',1,'pipewire.c']]],
-  ['pw_5fwork_5fqueue_5fadd_464',['pw_work_queue_add',['../group__pw__work__queue.html#ga31cc6b38eda61a244c7d3fd9024a74db',1,'work-queue.c']]],
-  ['pw_5fwork_5fqueue_5fcancel_465',['pw_work_queue_cancel',['../group__pw__work__queue.html#ga56673e78071d8a9eb28805331c8b2245',1,'work-queue.c']]],
-  ['pw_5fwork_5fqueue_5fcomplete_466',['pw_work_queue_complete',['../group__pw__work__queue.html#ga7a8bde683bc6cb8091a7d7be9df250fc',1,'work-queue.c']]],
-  ['pw_5fwork_5fqueue_5fdestroy_467',['pw_work_queue_destroy',['../group__pw__work__queue.html#gaa9e1df12736d075ba973a19f4333c2eb',1,'work-queue.c']]],
-  ['pw_5fwork_5fqueue_5fnew_468',['pw_work_queue_new',['../group__pw__work__queue.html#gacf03a683177510e35a3859ac16a08119',1,'work-queue.c']]],
-  ['pwtest_5fget_5fcontext_469',['pwtest_get_context',['../group__pwtest.html#ga7f5e4cd81dea4d1c31d004e3c48c597a',1,'pwtest.h']]],
-  ['pwtest_5fget_5fiteration_470',['pwtest_get_iteration',['../group__pwtest.html#ga135297caa69f5e14b2b20148850d080b',1,'pwtest.h']]],
-  ['pwtest_5fget_5fprops_471',['pwtest_get_props',['../group__pwtest.html#gae28b2ed45d205b93298f6c85f9cf6913',1,'pwtest.h']]],
-  ['pwtest_5fmkstemp_472',['pwtest_mkstemp',['../group__pwtest.html#ga5a5ba20824f92f66f86a8d1656db0ea5',1,'pwtest.h']]],
-  ['pwtest_5fspa_5fplugin_5fdestroy_473',['pwtest_spa_plugin_destroy',['../group__pwtest.html#ga3abfb07ed321c803757a34edcf56ef73',1,'pwtest.h']]],
-  ['pwtest_5fspa_5fplugin_5fload_5finterface_474',['pwtest_spa_plugin_load_interface',['../group__pwtest.html#ga0bc59dec6ed4bae2c6c03aea2c8789ae',1,'pwtest.h']]],
-  ['pwtest_5fspa_5fplugin_5fnew_475',['pwtest_spa_plugin_new',['../group__pwtest.html#ga1108ba45f915c9df17cc28357a21f5bf',1,'pwtest.h']]],
-  ['pwtest_5fspa_5fplugin_5ftry_5fload_5finterface_476',['pwtest_spa_plugin_try_load_interface',['../group__pwtest.html#ga7e85c98847c3522c3494af29a21f1e75',1,'pwtest.h']]],
-  ['pwtest_5fspawn_477',['pwtest_spawn',['../group__pwtest.html#ga71b64f3667b94c8200d47c3e28cff9e5',1,'pwtest.h']]]
+  ['pw_5fstrv_5ffind_443',['pw_strv_find',['../group__pw__utils.html#ga0ff9fdcc34105fadd73b9feac583188b',1,'utils.c']]],
+  ['pw_5fstrv_5ffind_5fcommon_444',['pw_strv_find_common',['../group__pw__utils.html#gaaae124fb2f76b6caaf2fd424b2e3a7f0',1,'utils.c']]],
+  ['pw_5fstrv_5fparse_445',['pw_strv_parse',['../group__pw__utils.html#gab14911d7b202c1f20ccbb175be94fd0d',1,'utils.c']]],
+  ['pw_5fthread_5ffill_5fattr_446',['pw_thread_fill_attr',['../group__pw__thread.html#ga09ac2a140526a285e1af5e7ddd2fe672',1,'thread.c']]],
+  ['pw_5fthread_5floop_5faccept_447',['pw_thread_loop_accept',['../group__pw__thread__loop.html#ga7cc82c62d85014248b66db0947e4f087',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fadd_5flistener_448',['pw_thread_loop_add_listener',['../group__pw__thread__loop.html#ga4b32a1682ab076c733bed42808037328',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fdestroy_449',['pw_thread_loop_destroy',['../group__pw__thread__loop.html#ga58bf781b6f987e80d4a7a6796551dfb1',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fget_5floop_450',['pw_thread_loop_get_loop',['../group__pw__thread__loop.html#ga4f2403d0004550ba89f76af4df63dfaf',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fget_5ftime_451',['pw_thread_loop_get_time',['../group__pw__thread__loop.html#ga7257709ce22560b28da2525f812485e5',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fin_5fthread_452',['pw_thread_loop_in_thread',['../group__pw__thread__loop.html#gacb9c26a513d752803fd272a4ea2bc891',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5flock_453',['pw_thread_loop_lock',['../group__pw__thread__loop.html#gaa7996893e812e9eec61f786d1c691c54',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fnew_454',['pw_thread_loop_new',['../group__pw__thread__loop.html#gad05bec2017f1081bccec2f0def34e9d3',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fnew_5ffull_455',['pw_thread_loop_new_full',['../group__pw__thread__loop.html#gabdc2e68dfd070fe58770143f184fc026',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fsignal_456',['pw_thread_loop_signal',['../group__pw__thread__loop.html#gaf9bc8dd348d05b095139f5a55ac5a4b0',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fstart_457',['pw_thread_loop_start',['../group__pw__thread__loop.html#ga22e8e0f011e6406a4201a28b4592862e',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fstop_458',['pw_thread_loop_stop',['../group__pw__thread__loop.html#ga856c3aec5718bceb92d6169c42062186',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5ftimed_5fwait_459',['pw_thread_loop_timed_wait',['../group__pw__thread__loop.html#ga3eb85aa843de70d0488aa25aa2dc361c',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5ftimed_5fwait_5ffull_460',['pw_thread_loop_timed_wait_full',['../group__pw__thread__loop.html#gaf191188f2dc2ddfbc1e9bb84764709eb',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5funlock_461',['pw_thread_loop_unlock',['../group__pw__thread__loop.html#ga1f8042dce9da459ec61b6f3a2d6852d8',1,'thread-loop.c']]],
+  ['pw_5fthread_5floop_5fwait_462',['pw_thread_loop_wait',['../group__pw__thread__loop.html#gae97c812b1fa7696909d3e4419e4e079e',1,'thread-loop.c']]],
+  ['pw_5fthread_5futils_5fget_463',['pw_thread_utils_get',['../group__pw__thread.html#ga4f44f914821635ec123cf0a0ae2d0b5d',1,'thread.c']]],
+  ['pw_5fthread_5futils_5fset_464',['pw_thread_utils_set',['../group__pw__thread.html#ga57b388a269e2682fd9bc46bb9f46efec',1,'thread.c']]],
+  ['pw_5ftype_5finfo_465',['pw_type_info',['../group__pw__type.html#ga7fff23c226b8e3b4c6b172be4bd2401a',1,'pipewire.c']]],
+  ['pw_5funload_5fspa_5fhandle_466',['pw_unload_spa_handle',['../group__pw__pipewire.html#gaf3d7686492ea5032eb135cddf21d3da2',1,'pipewire.c']]],
+  ['pw_5fwork_5fqueue_5fadd_467',['pw_work_queue_add',['../group__pw__work__queue.html#ga31cc6b38eda61a244c7d3fd9024a74db',1,'work-queue.c']]],
+  ['pw_5fwork_5fqueue_5fcancel_468',['pw_work_queue_cancel',['../group__pw__work__queue.html#ga56673e78071d8a9eb28805331c8b2245',1,'work-queue.c']]],
+  ['pw_5fwork_5fqueue_5fcomplete_469',['pw_work_queue_complete',['../group__pw__work__queue.html#ga7a8bde683bc6cb8091a7d7be9df250fc',1,'work-queue.c']]],
+  ['pw_5fwork_5fqueue_5fdestroy_470',['pw_work_queue_destroy',['../group__pw__work__queue.html#gaa9e1df12736d075ba973a19f4333c2eb',1,'work-queue.c']]],
+  ['pw_5fwork_5fqueue_5fnew_471',['pw_work_queue_new',['../group__pw__work__queue.html#gacf03a683177510e35a3859ac16a08119',1,'work-queue.c']]],
+  ['pwtest_5fget_5fcontext_472',['pwtest_get_context',['../group__pwtest.html#ga7f5e4cd81dea4d1c31d004e3c48c597a',1,'pwtest.h']]],
+  ['pwtest_5fget_5fiteration_473',['pwtest_get_iteration',['../group__pwtest.html#ga135297caa69f5e14b2b20148850d080b',1,'pwtest.h']]],
+  ['pwtest_5fget_5fprops_474',['pwtest_get_props',['../group__pwtest.html#gae28b2ed45d205b93298f6c85f9cf6913',1,'pwtest.h']]],
+  ['pwtest_5fmkstemp_475',['pwtest_mkstemp',['../group__pwtest.html#ga5a5ba20824f92f66f86a8d1656db0ea5',1,'pwtest.h']]],
+  ['pwtest_5fspa_5fplugin_5fdestroy_476',['pwtest_spa_plugin_destroy',['../group__pwtest.html#ga3abfb07ed321c803757a34edcf56ef73',1,'pwtest.h']]],
+  ['pwtest_5fspa_5fplugin_5fload_5finterface_477',['pwtest_spa_plugin_load_interface',['../group__pwtest.html#ga0bc59dec6ed4bae2c6c03aea2c8789ae',1,'pwtest.h']]],
+  ['pwtest_5fspa_5fplugin_5fnew_478',['pwtest_spa_plugin_new',['../group__pwtest.html#ga1108ba45f915c9df17cc28357a21f5bf',1,'pwtest.h']]],
+  ['pwtest_5fspa_5fplugin_5ftry_5fload_5finterface_479',['pwtest_spa_plugin_try_load_interface',['../group__pwtest.html#ga7e85c98847c3522c3494af29a21f1e75',1,'pwtest.h']]],
+  ['pwtest_5fspawn_480',['pwtest_spawn',['../group__pwtest.html#ga71b64f3667b94c8200d47c3e28cff9e5',1,'pwtest.h']]]
 ];
