@@ -1,16 +1,16 @@
 var indexSectionsWithContent =
 {
-  0: "_abcdefghijklmnopqrstuvwxyz",
+  0: "0123456789_abcdefghijklmnopqrstuvwxyz",
   1: "ips",
   2: "abcdfghijlmnprstuvw",
-  3: "_ps",
+  3: "ps",
   4: "_abcdefghijklmnopqrstuvwxyz",
   5: "ps",
   6: "ps",
   7: "_ps",
   8: "_eps",
-  9: "abcdefghijklmnprstuw",
-  10: "acdlmopst"
+  9: "abcdefghijklmnpqrstuw",
+  10: "123456abcdefgijlmnoprstuvxz"
 };
 
 var indexSectionNames =
